@@ -1,3 +1,4 @@
+from http import HTTPStatus
 from tabulate import tabulate
 from ...utils.env_keys import REPORT_ERROR_KEY
 from ...utils.http_client import LaunchableClient
@@ -19,6 +20,12 @@ def subset(subset_id):
     try:
         client = LaunchableClient()
         res = client.request("get", "subset/{}".format(subset_id))
+
+        if res.status_code == HTTPStatus.NOT_FOUND:
+            click.echo(click.style(
+                "Subset {} not found. Check subset ID and try again.".format(subset_id), 'yellow'), err=True)
+            exit(1)
+
         res.raise_for_status()
         subset = res.json()["testPaths"]
         rest = res.json()["rest"]
@@ -28,7 +35,7 @@ def subset(subset_id):
         else:
             click.echo(e, err=True)
         click.echo(click.style(
-            "Warning: the failed to inspect subset", fg='yellow'),
+            "Warning: failed to inspect subset", fg='yellow'),
             err=True)
 
     header = ["Order", "Test Path", "In Subset", "Estimated duration (sec)"]
